USE @DBNAME@
GO

/*
 * This script attempts to schedule a run of the oo_prune_run_history stored procedure.
 * Please set the parameters to your preference.
 */
DECLARE @dbName VARCHAR(128),
        @dbUser VARCHAR(32),
        @jobName VARCHAR(128),
        @jobScheduleName VARCHAR(128),           
        @jobDesc VARCHAR(512),
        @jobID UNIQUEIDENTIFIER,
        @jobStartTime VARCHAR(12),
        @ooCommand VARCHAR(1024),
        @hours_retained INTEGER,
        @log_file VARCHAR(1024) 


/* how many hours to keep (calculated from the last known start_time in the table run_history) */           
SET @hours_retained = 2;

/* what user do you want the job to run as, defaults to current user */
SELECT @dbUser = CURRENT_USER;

/* what is the database you want pruned, defaults to current database */
SET @dbName = DB_NAME(DB_ID());

/* how to call the job */
SET @jobName = 'oo_prune_run_history_job' ;

SET @jobScheduleName = 'schedule for ' + @jobName;

SET @jobDesc = 'Purge run histories older than '
        + CAST(@hours_retained AS VARCHAR)
        + ' hours';

/*
 * where to log the output of the job (you can also see this output if you view the detailed job history in SQLAgent)
 * 
 * Note that the success of writing this log file depends on
 * how the user that runs the procedure may be set up (i.e
 * what type of system user is it associated with, and what
 * type of permissions are there for the file).
 */
SET @log_file = 'C:\tmp\oo_prune_history_job.log';

/* check if SQLAgent is running */
IF (SELECT count(*) 
      FROM Master.dbo.SysProcesses 
     WHERE Program_Name = 'SQLAgent - Generic Refresher') = 0 
BEGIN
    RAISERROR('Could not schedule procedure oo_prune_run_history: SQLAgent is not running!', 0, 1) 
         WITH NOWAIT
    RETURN;
END
        
SET @ooCommand = 'EXEC dbo.oo_prune_run_history ' 
        + '@keep_this_many_hours = ' 
        + CAST(@hours_retained AS VARCHAR)
        + ', @verbose = 2';

/* create a job */
EXEC msdb..sp_add_job
    @job_name = @jobName,
    @enabled = 1,
    @description = @jobDesc,
    @job_id = @jobID OUTPUT;


/* add target server to the job */
EXEC msdb..sp_add_jobserver 
    @job_id = @jobID, 
    @server_name = @@SERVERNAME;

-- create step1, actual command
EXEC msdb..sp_add_jobstep
    @job_id = @jobID,
    @step_name = 'Run procedure oo_prune_run_history',
    @subsystem = 'TSQL',
    @command = @ooCommand,
    @database_name = @dbName,
    @database_user_name = @dbUser,
    @output_file_name = @log_file,
    @flags = 2; -- append to output file.
  
-- start the job 10 minutes from now.
-- Schedule proc requires HHMMSS. CONVERT(8) returns HH:MM:SS
--SET @jobStartTime = REPLACE(CONVERT(VARCHAR, DATEADD(minute, 10, GETDATE()), 8), ':', '');

-- schedule the job
EXEC msdb..sp_add_jobschedule
    @job_id = @jobID,
    @name = @jobScheduleName,
    @enabled = 1,
    @freq_type = 4, -- daily
    @freq_interval = 1, 
    @freq_subday_type = 8, -- hourly
    @freq_subday_interval = 2; -- every 2 hours

GO       
