USE @DBNAME@
GO

DROP PROCEDURE dbo.oo_upgrade_history_schema
GO

CREATE PROCEDURE dbo.oo_upgrade_history_schema
/* This procedure finds out if the db is at some old version that needs some 
 * DDL to implement cascaded deletes and if so, it alters the foreign keys
 * to have the proper cascades.
 */
AS
    /* find out the build version so we know if we need to do some schema altering */
    DECLARE @need_alters INTEGER ;
    SET @need_alters = 0;

  
    SELECT @need_alters=1
      FROM dbo.build_info
     WHERE dri_time IN (SELECT max(dri_time) FROM dbo.build_info)
       AND ((version LIKE '7.0%') OR (version LIKE '7.10%'));
    
    /* only do this if version is < 7.11 !!! */
    IF (@need_alters <> 0)
    BEGIN
        
		RAISERROR('Preparing old schema for pruning ...', 0,1) WITH NOWAIT;

        /** this may fail for some versions because the constraint has already been dropped. That's ok. */        
        ALTER TABLE dbo.runstep_history DROP CONSTRAINT fk_hist_rstep2parent;
    
        /** create index if not there already */
        CREATE INDEX idx_hist_prop_runhist_id ON dbo.property_history(run_hist_id);
    
        /* replace some of the foreign keys generated by hibernate 
        with the same foreign keys, but with DELETE CASCADE */
        ALTER TABLE dbo.runstep_history 
              DROP CONSTRAINT fk_hist_rstep2run;
    
        ALTER TABLE dbo.runstep_history 
              ADD CONSTRAINT fk_hist_rstep2run 
              FOREIGN KEY(run_history_id) 
              REFERENCES run_history
              ON DELETE CASCADE;
    
        ALTER TABLE dbo.property_history 
              DROP CONSTRAINT fk_hist_prop2rstep ;
    
        ALTER TABLE dbo.property_history 
              ADD CONSTRAINT fk_hist_prop2rstep 
              FOREIGN KEY (runstep_hist_id) 
              REFERENCES runstep_history(oid)
              ON DELETE CASCADE;
    END;
	
    RETURN NULL;

-- END PROCEDURE
GO    
